deeplink property
Where tapping the message itself should take the user, independently of any button.
Implementation
final String? deeplink;
Where tapping the message itself should take the user, independently of any button.
final String? deeplink;