AppwinInAppContent class

Constructors

AppwinInAppContent({String? title, String? body, String? imageUrl, String? deeplink, List<AppwinInAppButton>? buttons})
const
AppwinInAppContent.fromMap(Map map)
factory

Properties

body String?
final
buttons List<AppwinInAppButton>?
final
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited