AppwinInAppMessage class

An in-app message the server has queued for this device.

Constructors

AppwinInAppMessage({required String id, required String campaignId, required String deliveryId, required String channel, required String format, required AppwinInAppContent content})
const
AppwinInAppMessage.fromMap(Map map)
factory

Properties

campaignId String
final
channel String
final
content AppwinInAppContent
final
deliveryId String
final
format String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited