AppwinNotificationsMethodChannel class
- Inheritance
-
- Object
- PlatformInterface
- AppwinNotificationsPlatform
- AppwinNotificationsMethodChannel
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetchPendingMessages(
) → Future< List< AppwinInAppMessage> > -
override
-
getPlatformVersion(
) → Future< String?> -
override
-
initialize(
) → Future< AppwinInitResult> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
presentPendingMessages(
) → Future< void> -
override
-
registerPushToken(
{required String token, bool pushOptIn = true}) → Future< void> -
override
-
start(
{bool requestPushPermission = true}) → Future< void> -
override
-
stop(
) → Future< void> -
override
-
syncOnAppOpen(
) → Future< List< AppwinInAppMessage> > -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
track(
{required String deliveryId, required AppwinTrackEvent event, int? buttonIndex}) → Future< void> -
override
-
trackEvent(
{required AppwinAutomationEvent event, String? eventName, Map< String, String> ? properties}) → Future<void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited