AppwinNotificationsPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • AppwinNotificationsPlatform
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchPendingMessages() Future<List<AppwinInAppMessage>>
getPlatformVersion() Future<String?>
initialize() Future<AppwinInitResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
presentPendingMessages() Future<void>
registerPushToken({required String token, bool pushOptIn = true}) Future<void>
start({bool requestPushPermission = true}) Future<void>
stop() Future<void>
syncOnAppOpen() Future<List<AppwinInAppMessage>>
toString() String
A string representation of this object.
inherited
track({required String deliveryId, required AppwinTrackEvent event, int? buttonIndex}) Future<void>
trackEvent({required AppwinAutomationEvent event, String? eventName, Map<String, String>? properties}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AppwinNotificationsPlatform
getter/setter pair